@@ -16,11 +16,11 @@ class Shop(Service):
         """
         return self._callapi("shop/category", get={"id": id})
 
-    def get_currencies_list(self):
+    def get_currencies_list(self, order_id=None):
         """
         :rtype : list of Currency|Collection
         """
-        return self._callapi("shop/currencies")
+        return self._callapi("shop/currencies", get={"order_id": order_id})
 
     def get_currency_by_id(self, id, order_id=None):
         """
@@ -405,6 +405,39 @@ class System(Service):
 # noinspection PyShadowingBuiltins
 
 
+class Partner(Service):
+
+    def history_all_ref_codes(self, after_id=None):
+        """
+        :rtype : list of Stdclass|list
+        """
+        return self._callapi("partner/ref/all", get={"after_id": after_id})
+
+    def check_ref_code(self, code):
+        """
+        :rtype : bool
+        """
+        return self._callapi("partner/ref/check", get={"code": code})
+
+    def generate_ref_code(self):
+        """
+        :rtype : str
+        """
+        return self._callapi("partner/ref/generate")
+
+    def history_ref_code(self, code, limit=None, offset=None):
+        """
+        :rtype : list of Stdclass|list
+        """
+        return self._callapi(
+            "partner/ref/history",
+            get={
+                "code": code,
+                "limit": limit,
+                "offset": offset})
+# noinspection PyShadowingBuiltins
+
+
 class Validation(Service):
 
     def validate_order(self, postObject):
@@ -521,5 +554,6 @@ class Manager(object):
         self.users = Users(apiclient)
         self.invoices = Invoices(apiclient)
         self.system = System(apiclient)
+        self.partner = Partner(apiclient)
         self.validation = Validation(apiclient)
         self.geo = Geo(apiclient)
