@@ -10,8 +10,8 @@ def get_category_by_id(id):
     return get_apiclient().services.shop.get_category_by_id(id)
 
 
-def get_currencies_list():
-    return get_apiclient().services.shop.get_currencies_list()
+def get_currencies_list(order_id=None):
+    return get_apiclient().services.shop.get_currencies_list(order_id=order_id)
 
 
 def get_currency_by_id(id, order_id=None):
